Authors and Contributors
========================

## Origins

The project originally started in a Microsoft [repository](https://github.com/microsoft/times-excel-reader) under the name times-excel-reader. The following individuals contributed to its development at Microsoft:

- Sam Webster ([@samwebster](https://github.com/samwebster) - vast majority of work done in his own time)
- Tom Minka ([@tminka](https://github.com/tminka))
- Siddharth Krishna ([@siddharth-krishna](https://github.com/siddharth-krishna))
- Pashmina Cameron
- Sarah Lewis
- Krzysztof Maziarz
- Pavel Myshkov
- Alex Spengler
- Niloy Dey ([@niloyroot](https://github.com/niloyroot))
- Alejandro Romero Prieto ([@AlexRomeroPrieto](https://github.com/AlexRomeroPrieto))

## Current development

Since 2023, the project has been developed as [xl2times](https://github.com/etsap-TIMES/xl2times) under [IEA-ETSAP](https://iea-etsap.org/). The following individuals contributed to its developement:

- Sam Webster ([@samwebster](https://github.com/samwebster))
- Siddharth Krishna ([@siddharth-krishna](https://github.com/siddharth-krishna))
- Olexandr Balyk ([@olejandro](https://github.com/olejandro))
- Sam West ([@SamRWest](https://github.com/SamRWest))

Special thanks to the current [TIMES](https://github.com/etsap-TIMES/TIMES_model/) maintainer Antti Lehtilä ([@Antti-L](https://github.com/Antti-L)) for his continued engagement and feedback.
